==> plantuml-gplv2-1.2021.9.tar.gz: src/net/sourceforge/plantuml/math/PSystemMathFactory.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2020, Arnaud Roques
 *
 * Project Info:  https://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * https://plantuml.com/patreon (only 1$ per month!)
 * https://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 *
 * Original Author:  Arnaud Roques
 */
package net.sourceforge.plantuml.math;

import net.sourceforge.plantuml.command.PSystemBasicFactory;
import net.sourceforge.plantuml.core.DiagramType;
import net.sourceforge.plantuml.core.UmlSource;

public class PSystemMathFactory extends PSystemBasicFactory<PSystemMath> {

	public PSystemMathFactory(DiagramType type) {
		super(type);
	}

	@Override
	public PSystemMath initDiagram(UmlSource source, String startLine) {
		if (getDiagramType() == DiagramType.MATH) {
			return new PSystemMath(source);
		}

		return null;
	}

	@Override
	public PSystemMath executeLine(UmlSource source, PSystemMath system, String line) {
		system.doCommandLine(line);
		return system;
	}

}

==> plantuml-gplv2-1.2022.5.tar.gz: src/net/sourceforge/plantuml/math/PSystemMathFactory.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2023, Arnaud Roques
 *
 * Project Info:  https://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * https://plantuml.com/patreon (only 1$ per month!)
 * https://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 *
 * Original Author:  Arnaud Roques
 */
package net.sourceforge.plantuml.math;

import net.sourceforge.plantuml.api.ThemeStyle;
import net.sourceforge.plantuml.command.PSystemBasicFactory;
import net.sourceforge.plantuml.core.DiagramType;
import net.sourceforge.plantuml.core.UmlSource;

public class PSystemMathFactory extends PSystemBasicFactory<PSystemMath> {

	public PSystemMathFactory(DiagramType type) {
		super(type);
	}

	@Override
	public PSystemMath initDiagram(ThemeStyle style, UmlSource source, String startLine) {
		if (getDiagramType() == DiagramType.MATH)
			return new PSystemMath(source);

		return null;
	}

	@Override
	public PSystemMath executeLine(ThemeStyle style, UmlSource source, PSystemMath system, String line) {
		system.doCommandLine(line);
		return system;
	}

}
